import 'package:flutter/material.dart';

import 'package:flutter_gen/gen_l10n/l10n.dart';
import 'package:vrouter/vrouter.dart';

import 'package:fluffychat/pages/chat_list/chat_list.dart';
import 'package:fluffychat/pages/chat_list/spaces_drawer.dart';
import 'package:fluffychat/widgets/avatar.dart';

class ChatListNavigationRail extends StatelessWidget {
  final ChatListController controller;

  const ChatListNavigationRail(this.controller, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final spaceHierarchy = SpacesDrawer.getSpaceHierarchy(controller);

    final currentIndex = controller.spacesEntries.indexWhere((space) =>
        controller.activeSpacesEntry.runtimeType == space.runtimeType &&
        (controller.activeSpaceId == space.getSpace(context)?.id));

    return SingleChildScrollView(
      child: SizedBox(
        // wasted 1.5 h for finding out the proper sizing mechanism...
        height: spaceHierarchy.length * 44 + 64 + 8,
        child: NavigationRail(
          destinations: List.generate(spaceHierarchy.length + 1, (i) {
            if (i == spaceHierarchy.length) {
              return NavigationRailDestination(
                icon: Tooltip(
                  message: L10n.of(context)!.archive,
                  child: const Icon(
                    Icons.archive_outlined,
                  ),
                ),
                label: Text(L10n.of(context)!.archive),
              );
            }
            final space = spaceHierarchy.keys.toList()[i];
            final room = space.getSpace(context);
            final active = currentIndex == i;
            return NavigationRailDestination(
              icon: Tooltip(
                  message: space.getName(context),
                  child: room == null
                      ? space.getIcon(active)
                      : Avatar(
                          size: Avatar.defaultSize / 2,
                          mxContent: room.avatar,
                          name: space.getName(context),
                        )),
              label: Text(
                space.getName(context),
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
              ),
            );
          }),
          selectedIndex: currentIndex,
          onDestinationSelected: (index) {
            if (index == spaceHierarchy.length) {
              VRouter.of(context).to('/archive');
            } else {
              controller.setActiveSpacesEntry(
                context,
                spaceHierarchy.keys.toList()[index],
              );
            }
          },
          labelType: NavigationRailLabelType.selected,
        ),
      ),
    );
  }
}
